@@ -3,80 +3,10 @@
 
 import os
 import argparse
-import logging
 import liquidluck
+from liquidluck.generator import build
 from liquidluck.options import enable_pretty_logging
-from liquidluck.options import g, settings
-from liquidluck.utils import import_object, walk_dir
-
-from liquidluck.writers.base import load_jinja
-
-
-def load_settings(path):
-    config = {}
-    execfile(path, {}, config)
-
-    for key in config:
-        setting = config[key]
-        if isinstance(setting, dict):
-            settings[key].update(setting)
-        else:
-            settings[key] = setting
-
-    g.output_directory = os.path.abspath(settings.output)
-    g.static_directory = os.path.abspath(settings.static_output)
-    logging.info('Load Settings Finished')
-
-
-def load_posts(path):
-    g.source_directory = path
-    readers = []
-    for name in settings.readers:
-        reader = settings.readers[name]
-        if reader:
-            readers.append(import_object(reader))
-
-    def detect_reader(filepath):
-        for Reader in readers:
-            reader = Reader(filepath)
-            if reader.support():
-                return reader.run()
-        return None
-
-    for filepath in walk_dir(path):
-        post = detect_reader(filepath)
-        if not post:
-            g.pure_files.append(filepath)
-        elif not post.date:
-            g.pure_pages.append(post)
-        elif post.public:
-            g.public_posts.append(post)
-        else:
-            g.secure_posts.append(post)
-
-    g.public_posts = sorted(g.public_posts, key=lambda o: o.date, reverse=True)
-    g.secure_posts = sorted(g.secure_posts, key=lambda o: o.date, reverse=True)
-
-    logging.info('Load Posts Finished')
-
-
-def write_posts():
-    writers = []
-    for name in settings.writers:
-        writer = settings.writers[name]
-        if writer:
-            writers.append(import_object(writer)())
-
-    load_jinja()
-
-    for writer in writers:
-        writer.run()
-
-
-def generate(config='settings.py'):
-    load_settings(config)
-    load_posts(settings.source)
-    write_posts()
+from liquidluck.options import g
 
 
 DEFAULT_SETTING = """
@@ -213,9 +143,6 @@ def install(keyword):
 
 def main():
     parser = argparse.ArgumentParser(prog='liquidluck')
-    parser.add_argument(
-        '-s', '--settings', default='settings.py', help='setting file'
-    )
 
     subparser = parser.add_subparsers(
         title='available commands', dest='subparser'
@@ -223,6 +150,8 @@ def main():
 
     subparser.add_parser(
         'create', help='create a blog repo',
+    ).add_argument(
+        '-s', '--settings', default='settings.py', help='setting file'
     )
 
     parser_gen = subparser.add_parser(
@@ -232,6 +161,9 @@ def main():
         '-v', '--verbose', action='store_true',
         help='show more logging'
     )
+    parser_gen.add_argument(
+        '-s', '--settings', default='settings.py', help='setting file'
+    )
 
     subparser.add_parser(
         'search', help='search theme'
@@ -249,6 +181,17 @@ def main():
         'version', help='show Felix Felicis version'
     )
 
+    parser_webhook = subparser.add_parser(
+        'webhook', help='start a webhook server',
+    )
+    parser_webhook.add_argument(
+        'daemon', nargs='?', default='start',
+    )
+    parser_webhook.add_argument(
+        '-p', '--port', nargs='?', default=8000,
+        help='server port'
+    )
+
     args = parser.parse_args()
 
     if args.subparser == 'version':
@@ -271,6 +214,11 @@ def main():
         create(args.settings)
         return
 
+    if args.subparser == 'webhook':
+        from liquidluck.webhook import webhook
+        webhook(args.port, args.daemon)
+        return
+
     #: args.subparser == 'build'
     if not os.path.exists(args.settings):
         answer = raw_input(
@@ -284,7 +232,7 @@ def main():
 
     g.detail_logging = args.verbose
     enable_pretty_logging()
-    generate(args.settings)
+    build(args.settings)
 
 
 if __name__ == '__main__':
